@@ -14,7 +14,7 @@ def _signed_int(edt):  # signed ints
 
 def _hh_mm(edt):  # basic time unit
     hh = int.from_bytes(edt[0:1], "big")
-    mm = int.from_bytes(edt[1:2], "big")
+    mm = str(int.from_bytes(edt[1:2], "big")).zfill(2)
     return f"{hh}:{mm}"
 
 def _to_string(edt):
@@ -84,6 +84,7 @@ EPC_SUPER_FUNCTIONS = {
     0x85: _int,
     0x8A: _008A,
     0x9A: _009A,
+    0x9D: _009X,
     0x9E: _009X,
     0x9F: _009X,
 }
